summaryrefslogtreecommitdiff
path: root/lib/util/samba_modules.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/util/samba_modules.h')
-rw-r--r--lib/util/samba_modules.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/lib/util/samba_modules.h b/lib/util/samba_modules.h
index ae7895eb12..5eb2a0dd1c 100644
--- a/lib/util/samba_modules.h
+++ b/lib/util/samba_modules.h
@@ -33,9 +33,11 @@ NTSTATUS samba_init_module(void);
#define SAMBA_INIT_MODULE "samba_init_module"
/**
* Obtain the init function from a shared library file
*/
-init_module_fn load_module(TALLOC_CTX *mem_ctx, const char *path);
+init_module_fn load_module(const char *path, bool is_probe, void **handle);
/**
* Run the specified init functions.
@@ -33,9 +33,11 @@ NTSTATUS samba_init_module(void);
#define SAMBA_INIT_MODULE "samba_init_module"
/**
- * Obtain the init function from a shared library file
+ * Obtain the init function from a shared library file.
+ *
+ * The handle to dlclose() in case of error is returns in *handle if handle is not NULL
*/